---
title: About 
layout: page 
date: 2014-01-10
---

Author
======

The Urubu software is written by Jan Decaluwe.

License
=======

The Urubu software is licensed under the [software_license].

The content on this documentation website is licensed
under the [content_license].

Development
===========

The Urubu software is developed on [github] in the [urubu_repo].

The documentation is developed as a website in a `gh-pages` branch in the same
repo. It can be accessed from the custom domain [urubu.jandecaluwe.com] but it
is hosted on [GitHub Pages].

[urubu.jandecaluwe.com]: http://urubu.jandecaluwe.com
[Github Pages]: http://pages.github.com

Theme
=====

The theme on this website is based on stock [bootstrap].

Trivia
======

An urubu is a brazilian vulture. [Urubu][Urubu_album] is also the 10th album of
Antonio Carlos Jobim, one of my favorite song composers.

[Urubu_album]: http://en.wikipedia.org/wiki/Urubu_(album)
